@@ -1,4 +1,4 @@
-from json_resource.exceptions import ResourceNotFound, ResourceExists, ValidationError
+from json_resource.exceptions import *
 from json_resource.instance import JSONInstance, ResourceMeta
 from json_resource.object import Object
 from json_resource.array import Array
