@@ -16,8 +16,9 @@ class ResourceMeta(type):
         if hasattr(result, 'type'):
             cls._types.append((result.type, result.blacklist, result))
 
-
-        if hasattr(result, 'schema') and result.schema is not None:
+        if (hasattr(result, 'schema') and
+                result.schema is not None and
+                result.schema.keys() == ['id']):
             result.schema.load()
 
         return result
