@@ -1,7 +1,10 @@
 import copy
+import re
+from gettext import gettext as _
+
 import pymongo
 
-from .exceptions import ResourceNotFound, ResourceExists
+from .exceptions import ResourceNotFound, ResourceExists, ValidationError
 
 
 class QuerySet(object):
@@ -96,8 +99,8 @@ class QuerySet(object):
         return result
 
     def filter(self, filter):
-        self._filter.update(filter)
-        return copy.deepcopy(self)
+        result = copy.deepcopy(self)
+        result._filter.update(filter)
 
         return result
 
@@ -143,7 +146,7 @@ class QuerySet(object):
 
         try:
             self.collection.insert(data, j=True)
-        except pymongo.errors.DuplicateKeyError:
+        except pymongo.errors.DuplicateKeyError, e:
             raise ResourceExists(resource.url)
 
     def save(self, resource, validate=True, upsert=True):
@@ -151,9 +154,22 @@ class QuerySet(object):
         data['_id'] = resource._id
         data['_meta'] = resource.meta
 
-        result = self.collection.update(
-            {'_id': resource._id}, data, upsert=upsert
-        )
+        try:
+            result = self.collection.update(
+                {'_id': resource._id}, data, upsert=upsert
+            )
+        except pymongo.errors.DuplicateKeyError, e:
+            query = re.search(
+                'index\: (?P<ns>[\w\-\.]+)\.\$(?P<name>\w+)', e.message
+            ).groupdict()
+            index = self.collection.database['system.indexes'].find_one(query)
+
+            error = {
+                'message': 'Already exists',
+                'validator': 'unique',
+                'path': '/' + index['key'].keys()[0]
+            }
+            raise ValidationError(error)
 
         if result['n'] == 0:
             raise ResourceNotFound(resource.url)
