@@ -11,7 +11,7 @@ class StoredResourceMeta(ResourceMeta):
     def __new__(cls, name, bases, dct):
         result = super(StoredResourceMeta, cls).__new__(cls, name, bases, dct)
 
-        if result.schema and not hasattr(result, 'objects'):
+        if result.schema and getattr(result, 'objects', None) is None:
             result.objects = QuerySet(
                 result
             )
@@ -38,7 +38,7 @@ class Resource(Object):
     def collection(cls):
         """ Return the collection in which the resources are saved.
         """
-        return cls.db[cls.schema['id']]
+        return cls.db()[cls.schema['id']]
 
     def load(self, **kwargs):
         """ Load the resource from the database.
@@ -84,3 +84,20 @@ class Resource(Object):
             return False
         else:
             return True
+
+    @classmethod
+    def indexes(cls):
+        for prop in cls.schema.get('unique', []):
+            yield prop, {'unique': True}
+
+        for prop in cls.schema.get('indexes', []):
+            yield prop, {}
+
+    @classmethod
+    def ensure_indexes(cls, background=True):
+        for prop, args in cls.indexes():
+            cls.collection().ensure_index(
+                prop,
+                background=background,
+                **args
+            )
